@@ -1,9 +1,9 @@
 //  boost quaternion.hpp header file
 
-//  (C) Copyright Hubert Holin 2001. Permission to copy, use, modify, sell and
-//  distribute this software is granted provided this copyright notice appears
-//  in all copies. This software is provided "as is" without express or implied
-//  warranty, and with no claim as to its suitability for any purpose.
+//  (C) Copyright Hubert Holin 2001.
+//  Distributed under the Boost Software License, Version 1.0. (See
+//  accompanying file LICENSE_1_0.txt or copy at
+//  http://www.boost.org/LICENSE_1_0.txt)
 
 // See http://www.boost.org for updates, documentation, and revision history.
 
@@ -611,7 +611,7 @@ namespace boost
                 tr[0] = rhs.real();                                                                     \
                 tr[1] = rhs.imag();                                                                     \
                                                                                                         \
-                type            mixam = BOOST_GET_VALARRAY(type,static_cast<type>(1)/abs(tr)).max();    \
+                type            mixam = (BOOST_GET_VALARRAY(type,static_cast<type>(1)/abs(tr)).max)();  \
                                                                                                         \
                 tr *= mixam;                                                                            \
                                                                                                         \
@@ -645,7 +645,7 @@ namespace boost
                 tr[0] = rhs.real();                                                  \
                 tr[1] = rhs.imag();                                                  \
                                                                                      \
-                type            mixam = static_cast<type>(1)/abs(tr).max();          \
+                type            mixam = static_cast<type>(1)/(abs(tr).max)();        \
                                                                                      \
                 tr *= mixam;                                                         \
                                                                                      \
@@ -678,7 +678,7 @@ namespace boost
                 tr[0] = rhs.real();                                                  \
                 tr[1] = rhs.imag();                                                  \
                                                                                      \
-                type            mixam = static_cast<type>(1)/abs(tr).max();          \
+                type            mixam = static_cast<type>(1)/(abs(tr).max)();        \
                                                                                      \
                 tr *= mixam;                                                         \
                                                                                      \
@@ -716,7 +716,7 @@ namespace boost
                 tr[2] = static_cast<type>(rhs.R_component_3());                                         \
                 tr[3] = static_cast<type>(rhs.R_component_4());                                         \
                                                                                                         \
-                type            mixam = BOOST_GET_VALARRAY(type,static_cast<type>(1)/abs(tr)).max();    \
+                type            mixam = (BOOST_GET_VALARRAY(type,static_cast<type>(1)/abs(tr)).max)();  \
                                                                                                         \
                 tr *= mixam;                                                                            \
                                                                                                         \
@@ -753,7 +753,7 @@ namespace boost
                 tr[2] = static_cast<type>(rhs.R_component_3());               \
                 tr[3] = static_cast<type>(rhs.R_component_4());               \
                                                                               \
-                type            mixam = static_cast<type>(1)/abs(tr).max();   \
+                type            mixam = static_cast<type>(1)/(abs(tr).max)(); \
                                                                               \
                 tr *= mixam;                                                  \
                                                                               \
@@ -789,7 +789,7 @@ namespace boost
                 tr[2] = static_cast<type>(rhs.R_component_3());               \
                 tr[3] = static_cast<type>(rhs.R_component_4());               \
                                                                               \
-                type            mixam = static_cast<type>(1)/abs(tr).max();   \
+                type            mixam = static_cast<type>(1)/(abs(tr).max)(); \
                                                                               \
                 tr *= mixam;                                                  \
                                                                               \
@@ -1587,9 +1587,9 @@ namespace boost
             BOOST_QUATERNION_VALARRAY_LOADER
             
 #if defined(__GNUC__) && __GNUC__ < 3
-            return(BOOST_GET_VALARRAY(T, abs(temp)).max());
+            return((BOOST_GET_VALARRAY(T, abs(temp)).max)());
 #else
-            return(abs(temp).max());
+            return((abs(temp).max)());
 #endif /* defined(__GNUC__) && (__GNUC__ < 3) */
         }
         
@@ -1623,9 +1623,9 @@ namespace boost
             BOOST_QUATERNION_VALARRAY_LOADER
             
 #if defined(__GNUC__) && __GNUC__ < 3
-            T            maxim = BOOST_GET_VALARRAY(T, abs(temp)).max();    // overflow protection
+            T            maxim = (BOOST_GET_VALARRAY(T, abs(temp)).max)();    // overflow protection
 #else
-            T            maxim = abs(temp).max();    // overflow protection
+            T            maxim = (abs(temp).max)();    // overflow protection
 #endif /* defined(__GNUC__) && (__GNUC__ < 3) */
             
             if    (maxim == static_cast<T>(0))
