@@ -1,17 +1,11 @@
 /* Boost interval/detail/c99_rounding_control.hpp file
  *
- * Copyright Jens Maurer 2000
- * Copyright Herv Brnnimann, Guillaume Melquiond, Sylvain Pion 2002
- * Permission to use, copy, modify, sell, and distribute this software
- * is hereby granted without fee provided that the above copyright notice
- * appears in all copies and that both that copyright notice and this
- * permission notice appear in supporting documentation,
+ * Copyright 2000 Jens Maurer
+ * Copyright 2002 Herv Brnnimann, Guillaume Melquiond, Sylvain Pion
  *
- * None of the above authors nor Polytechnic University make any
- * representation about the suitability of this software for any
- * purpose. It is provided "as is" without express or implied warranty.
- *
- * $Id: c99_rounding_control.hpp,v 1.3 2003/07/30 05:08:44 gmelquio Exp $
+ * Distributed under the Boost Software License, Version 1.0.
+ * (See accompanying file LICENSE_1_0.txt or
+ * copy at http://www.boost.org/LICENSE_1_0.txt)
  */
 
 #ifndef BOOST_NUMERIC_INTERVAL_DETAIL_C99_ROUNDING_CONTROL_HPP
@@ -24,7 +18,7 @@ namespace numeric {
 namespace interval_lib {
 namespace detail {
 
-struct c99_rounding_control
+struct c99_rounding_control: c99_rounding
 {
   template<class T>
   static T force_rounding(const T& r) { volatile T r_ = r; return r_; }
