@@ -19,9 +19,9 @@
 
 #include <iterator>
 
-#include <boost/numeric/ublas/config.hpp>
+#include <boost/numeric/ublas/exception.hpp>
 
-// Using GCC the following is missing:
+// Using older GCC the following is missing:
 //
 // namespace std {
 //
@@ -42,18 +42,16 @@
 
 namespace boost { namespace numeric { namespace ublas {
 
-#ifdef BOOST_UBLAS_NEED_CONVERSION
+  /** \brief Base class of all proxy classes that contain
+   *       a (redirectable) reference to an immutable object.
+   *
+   *       \param C the type of the container referred to
+   */
     template<class C>
-    class container_reference;
-#endif
-
-    template<class C>
-    class container_const_reference {
+    class container_const_reference:
+        private nonassignable {
     public:
         typedef C container_type;
-#ifdef BOOST_UBLAS_NEED_CONVERSION
-        typedef container_reference<container_type> container_reference;
-#endif
 
         BOOST_UBLAS_INLINE
         container_const_reference ():
@@ -61,11 +59,6 @@ namespace boost { namespace numeric { namespace ublas {
         BOOST_UBLAS_INLINE
         container_const_reference (const container_type &c):
             c_ (&c) {}
-#ifdef BOOST_UBLAS_NEED_CONVERSION
-        BOOST_UBLAS_INLINE
-        container_const_reference (const container_reference &c):
-            c_ (c.c ()) {}
-#endif
 
         BOOST_UBLAS_INLINE
         const container_type &operator () () const {
@@ -77,17 +70,25 @@ namespace boost { namespace numeric { namespace ublas {
             c_ = c;
             return *this;
         }
+        
+        // Closure comparison
+        BOOST_UBLAS_INLINE
+        bool same_closure (const container_const_reference &cr) const {
+            return c_ == cr.c_;
+        }
 
     private:
         const container_type *c_;
-
-        container_const_reference &operator = (const container_const_reference &) {
-            return *this;
-        }
     };
 
+  /** \brief Base class of all proxy classes that contain
+   *         a (redirectable) reference to a mutable object.
+   *
+   * \param C the type of the container referred to
+   */
     template<class C>
-    class container_reference {
+    class container_reference:
+        private nonassignable {
     public:
         typedef C container_type;
 
@@ -109,14 +110,25 @@ namespace boost { namespace numeric { namespace ublas {
             return *this;
         }
 
+        // Closure comparison
+        BOOST_UBLAS_INLINE
+        bool same_closure (const container_reference &cr) const {
+            return c_ == cr.c_;
+        }
+
     private:
         container_type *c_;
-
-        container_reference operator = (const container_reference &) {
-            return *this;
-        }
     };
 
+  /** \brief Base class of all forward iterators.
+   * 
+   *  \param IC the iterator category
+   *  \param I the derived iterator type
+   *  \param T the value type
+   * 
+   * The forward iterator can only proceed in one direction
+   * via the post increment operator.
+   */
     template<class IC, class I, class T>
     struct forward_iterator_base:
         public boost::iterator<IC, T> {
@@ -160,6 +172,15 @@ namespace boost { namespace numeric { namespace ublas {
     }
 #endif
 
+  /** \brief Base class of all bidirectional iterators.
+   *
+   * \param IC the iterator category
+   * \param I the derived iterator type
+   * \param T the value type
+   *
+   * The bidirectional iterator can proceed in both directions
+   * via the post increment and post decrement operator.
+   */
     template<class IC, class I, class T>
     struct bidirectional_iterator_base:
         public boost::iterator<IC, T> {
@@ -227,7 +248,20 @@ namespace boost { namespace numeric { namespace ublas {
     }
 #endif
 
+  /** \brief Base class of all random access iterators.
+   *
+   * \param IC the iterator category
+   * \param I the derived iterator type
+   * \param T the value type
+   * \param D the difference type, default: std::ptrdiff_t
+   *
+   * The random access iterator can proceed in both directions
+   * via the post increment/decrement operator or in larger steps
+   * via the +, - and +=, -= operators. The random access iterator
+   * is LessThan Comparable.
+   */
     template<class IC, class I, class T, class D = std::ptrdiff_t>
+    // ISSUE the default here seems rather dangerous as it can easlly be (silently) incorrect
     struct random_access_iterator_base:
         public boost::iterator<IC, T> {
         typedef I derived_iterator_type;
@@ -237,6 +271,16 @@ namespace boost { namespace numeric { namespace ublas {
         typedef D difference_type;
 #endif
 
+        /*
+         *  FIXME Need to explicitly pass derived_refernce_type as otherwise I undefined type or foward declared
+        typedef BOOST_UBLAS_TYPENAME derived_iterator_type::reference derived_reference_type;
+        // Indexed element
+        BOOST_UBLAS_INLINE
+        derived_reference_type operator [] (derived_difference_type n) {
+            return *(*this + n);
+        }
+        */
+
         // Arithmetic
         BOOST_UBLAS_INLINE
         derived_iterator_type operator ++ (int) {
@@ -365,6 +409,19 @@ namespace boost { namespace numeric { namespace ublas {
 
 #ifdef BOOST_MSVC_STD_ITERATOR
 
+  /** \brief Base class of all reverse iterators. (MSVC version)
+   *
+   * \param I the derived iterator type
+   * \param T the value type
+   * \param R the reference type
+   *
+   * The reverse iterator implements a bidirectional iterator
+   * reversing the elements of the underlying iterator. It
+   * implements most operators of a random access iterator.
+   *
+   * uBLAS extension: it.index()
+   */
+
     // Renamed this class from reverse_iterator to get
     // typedef reverse_iterator<...> reverse_iterator
     // working. Thanks to Gabriel Dos Reis for explaining this.
@@ -372,12 +429,12 @@ namespace boost { namespace numeric { namespace ublas {
     class reverse_iterator_base:
         public std::reverse_bidirectional_iterator<I, T, R> {
     public:
-        typedef std::size_t size_type;
-        typedef std::ptrdiff_t difference_type;
+        typedef typename I::container_type container_type;
+        typedef typename container_type::size_type size_type;
+        typedef typename I::difference_type difference_type;
         typedef I iterator_type;
         typedef T value_type;
         typedef R reference;
-        typedef typename I::container_type container_type;
 
         // Construction and destruction
         BOOST_UBLAS_INLINE
@@ -455,6 +512,20 @@ namespace boost { namespace numeric { namespace ublas {
         return it2.base () - it1.base ();
     }
 
+  /** \brief 1st base class of all matrix reverse iterators. (MSVC version)
+   *
+   * \param I the derived iterator type
+   * \param T the value type
+   * \param R the reference type
+   *
+   * The reverse iterator implements a bidirectional iterator
+   * reversing the elements of the underlying iterator. It
+   * implements most operators of a random access iterator.
+   *
+   * uBLAS extension: it.index1(), it.index2() and access to
+   * the dual iterator via begin(), end(), rbegin(), rend()
+   */
+
     // Renamed this class from reverse_iterator1 to get
     // typedef reverse_iterator1<...> reverse_iterator1
     // working. Thanks to Gabriel Dos Reis for explaining this.
@@ -462,12 +533,12 @@ namespace boost { namespace numeric { namespace ublas {
     class reverse_iterator_base1:
         public std::reverse_bidirectional_iterator<I, T, R> {
     public:
-        typedef std::size_t size_type;
-        typedef std::ptrdiff_t difference_type;
+        typedef typename I::container_type container_type;
+        typedef typename container_type::size_type size_type;
+        typedef typename I::difference_type difference_type;
         typedef I iterator_type;
         typedef T value_type;
         typedef R reference;
-        typedef typename I::container_type container_type;
         typedef typename I::dual_iterator_type dual_iterator_type;
         typedef typename I::dual_reverse_iterator_type dual_reverse_iterator_type;
 
@@ -574,6 +645,22 @@ namespace boost { namespace numeric { namespace ublas {
         return it2.base () - it1.base ();
     }
 
+  /** \brief 2nd base class of all matrix reverse iterators. (MSVC version)
+   *
+   * \param I the derived iterator type
+   * \param T the value type
+   * \param R the reference type
+   *
+   * The reverse iterator implements a bidirectional iterator
+   * reversing the elements of the underlying iterator. It
+   * implements most operators of a random access iterator.
+   *
+   * uBLAS extension: it.index1(), it.index2() and access to
+   * the dual iterator via begin(), end(), rbegin(), rend()
+   *
+   * Note: This class is _identical_ to reverse_iterator_base1
+   */
+
     // Renamed this class from reverse_iterator2 to get
     // typedef reverse_iterator2<...> reverse_iterator2
     // working. Thanks to Gabriel Dos Reis for explaining this.
@@ -581,12 +668,12 @@ namespace boost { namespace numeric { namespace ublas {
     class reverse_iterator_base2:
         public std::reverse_bidirectional_iterator<I, T, R> {
     public:
-        typedef std::size_t size_type;
-        typedef std::ptrdiff_t difference_type;
+        typedef typename I::container_type container_type;
+        typedef typename container_type::size_type size_type;
+        typedef typename I::difference_type difference_type;
         typedef I iterator_type;
         typedef T value_type;
         typedef R reference;
-        typedef typename I::container_type container_type;
         typedef typename I::dual_iterator_type dual_iterator_type;
         typedef typename I::dual_reverse_iterator_type dual_reverse_iterator_type;
 
@@ -695,6 +782,19 @@ namespace boost { namespace numeric { namespace ublas {
 
 #else
 
+  /** \brief Base class of all reverse iterators. (non-MSVC version)
+   *
+   * \param I the derived iterator type
+   * \param T the value type
+   * \param R the reference type
+   *
+   * The reverse iterator implements a bidirectional iterator
+   * reversing the elements of the underlying iterator. It
+   * implements most operators of a random access iterator.
+   *
+   * uBLAS extension: it.index()
+   */
+
     // Renamed this class from reverse_iterator to get
     // typedef reverse_iterator<...> reverse_iterator
     // working. Thanks to Gabriel Dos Reis for explaining this.
@@ -702,10 +802,10 @@ namespace boost { namespace numeric { namespace ublas {
     class reverse_iterator_base:
         public std::reverse_iterator<I> {
     public:
-        typedef std::size_t size_type;
-        typedef std::ptrdiff_t difference_type;
-        typedef I iterator_type;
         typedef typename I::container_type container_type;
+        typedef typename container_type::size_type size_type;
+        typedef typename I::difference_type difference_type;
+        typedef I iterator_type;
 
         // Construction and destruction
         BOOST_UBLAS_INLINE
@@ -715,7 +815,7 @@ namespace boost { namespace numeric { namespace ublas {
         reverse_iterator_base (const iterator_type &it):
             std::reverse_iterator<iterator_type> (it) {}
 
-#ifdef BOOST_UBLAS_REVERSE_ITERATOR_OVERLOADS
+#ifndef BOOST_UBLAS_NO_REVERSE_ITERATOR_OVERLOADS
         // Arithmetic
         BOOST_UBLAS_INLINE
         reverse_iterator_base &operator ++ () {
@@ -777,7 +877,6 @@ namespace boost { namespace numeric { namespace ublas {
 
         BOOST_UBLAS_INLINE
         const container_type &operator () () const {
-            // Comeau recommends...
             return this->base () ();
         }
 
@@ -815,6 +914,18 @@ namespace boost { namespace numeric { namespace ublas {
     }
 #endif
 
+  /** \brief 1st base class of all matrix reverse iterators. (non-MSVC version)
+   *
+   * \param I the derived iterator type
+   *
+   * The reverse iterator implements a bidirectional iterator
+   * reversing the elements of the underlying iterator. It
+   * implements most operators of a random access iterator.
+   *
+   * uBLAS extension: it.index1(), it.index2() and access to
+   * the dual iterator via begin(), end(), rbegin(), rend()
+   */
+
     // Renamed this class from reverse_iterator1 to get
     // typedef reverse_iterator1<...> reverse_iterator1
     // working. Thanks to Gabriel Dos Reis for explaining this.
@@ -822,10 +933,10 @@ namespace boost { namespace numeric { namespace ublas {
     class reverse_iterator_base1:
         public std::reverse_iterator<I> {
     public:
-        typedef std::size_t size_type;
-        typedef std::ptrdiff_t difference_type;
-        typedef I iterator_type;
         typedef typename I::container_type container_type;
+        typedef typename container_type::size_type size_type;
+        typedef typename I::difference_type difference_type;
+        typedef I iterator_type;
         typedef typename I::dual_iterator_type dual_iterator_type;
         typedef typename I::dual_reverse_iterator_type dual_reverse_iterator_type;
 
@@ -837,7 +948,7 @@ namespace boost { namespace numeric { namespace ublas {
         reverse_iterator_base1 (const iterator_type &it):
             std::reverse_iterator<iterator_type> (it) {}
 
-#ifdef BOOST_UBLAS_REVERSE_ITERATOR_OVERLOADS
+#ifndef BOOST_UBLAS_NO_REVERSE_ITERATOR_OVERLOADS
         // Arithmetic
         BOOST_UBLAS_INLINE
         reverse_iterator_base1 &operator ++ () {
@@ -964,6 +1075,20 @@ namespace boost { namespace numeric { namespace ublas {
     }
 #endif
 
+  /** \brief 2nd base class of all matrix reverse iterators. (non-MSVC version)
+   *
+   * \param I the derived iterator type
+   *
+   * The reverse iterator implements a bidirectional iterator
+   * reversing the elements of the underlying iterator. It
+   * implements most operators of a random access iterator.
+   *
+   * uBLAS extension: it.index1(), it.index2() and access to
+   * the dual iterator via begin(), end(), rbegin(), rend()
+   *
+   * Note: this type is _identical_ to reverse_iterator_base1
+   */
+
     // Renamed this class from reverse_iterator2 to get
     // typedef reverse_iterator2<...> reverse_iterator2
     // working. Thanks to Gabriel Dos Reis for explaining this.
@@ -971,10 +1096,10 @@ namespace boost { namespace numeric { namespace ublas {
     class reverse_iterator_base2:
         public std::reverse_iterator<I> {
     public:
-        typedef std::size_t size_type;
-        typedef std::ptrdiff_t difference_type;
-        typedef I iterator_type;
         typedef typename I::container_type container_type;
+        typedef typename container_type::size_type size_type;
+        typedef typename I::difference_type difference_type;
+        typedef I iterator_type;
         typedef typename I::dual_iterator_type dual_iterator_type;
         typedef typename I::dual_reverse_iterator_type dual_reverse_iterator_type;
 
@@ -986,7 +1111,7 @@ namespace boost { namespace numeric { namespace ublas {
         reverse_iterator_base2 (const iterator_type &it):
             std::reverse_iterator<iterator_type> (it) {}
 
-#ifdef BOOST_UBLAS_REVERSE_ITERATOR_OVERLOADS
+#ifndef BOOST_UBLAS_NO_REVERSE_ITERATOR_OVERLOADS
         // Arithmetic
         BOOST_UBLAS_INLINE
         reverse_iterator_base2 &operator ++ () {
@@ -1115,6 +1240,18 @@ namespace boost { namespace numeric { namespace ublas {
 
 #endif
 
+  /** \brief A class implementing an indexed random access iterator.
+   *
+   * \param C the mutable container type
+   * \param IC the iterator category
+   *
+   * This class implements a random access iterator. The current 
+   * position is stored as the unsigned integer it_ and the
+   * values are accessed via operator()(it_) of the container.
+   *
+   * uBLAS extension: index()
+   */
+
     template<class C, class IC>
     class indexed_iterator:
         public container_reference<C>,
@@ -1243,6 +1380,21 @@ namespace boost { namespace numeric { namespace ublas {
     }
 #endif
 
+  /** \brief A class implementing an indexed random access iterator.
+   *
+   * \param C the mutable container type
+   * \param IC the iterator category
+   *
+   * This class implements a random access iterator. The current 
+   * position is stored as the unsigned integer \c it_ and the
+   * values are accessed via \c operator()(it_) of the container.
+   *
+   * uBLAS extension: \c index()
+   *
+   * Note: there is an automatic conversion from 
+   * \c indexed_iterator to \c indexed_const_iterator
+   */
+
     template<class C, class IC>
     class indexed_const_iterator:
         public container_const_reference<C>,
@@ -1380,6 +1532,24 @@ namespace boost { namespace numeric { namespace ublas {
     template<class C, class IC>
     class indexed_iterator2;
 
+  /** \brief A class implementing an indexed random access iterator 
+   * of a matrix.
+   *
+   * \param C the mutable container type
+   * \param IC the iterator category
+   *
+   * This class implements a random access iterator. The current
+   * position is stored as two unsigned integers \c it1_ and \c it2_
+   * and the values are accessed via \c operator()(it1_, it2_) of the
+   * container. The iterator changes the first index.
+   *
+   * uBLAS extension: \c index1(), \c index2() and access to the
+   * dual iterator via \c begin(), \c end(), \c rbegin() and \c rend()
+   *
+   * Note: The container has to support the \code find2(rank, i, j) \endcode 
+   * method
+   */
+
     template<class C, class IC>
     class indexed_iterator1:
         public container_reference<C>, 
@@ -1544,6 +1714,26 @@ namespace boost { namespace numeric { namespace ublas {
     template<class C, class IC>
     class indexed_const_iterator2;
 
+  /** \brief A class implementing an indexed random access iterator 
+   * of a matrix.
+   *
+   * \param C the (immutable) container type
+   * \param IC the iterator category
+   *
+   * This class implements a random access iterator. The current
+   * position is stored as two unsigned integers \c it1_ and \c it2_
+   * and the values are accessed via \c operator()(it1_, it2_) of the
+   * container. The iterator changes the first index.
+   *
+   * uBLAS extension: \c index1(), \c index2() and access to the
+   * dual iterator via \c begin(), \c end(), \c rbegin() and \c rend()
+   *
+   * Note 1: The container has to support the find2(rank, i, j) method
+   *
+   * Note 2: there is an automatic conversion from 
+   * \c indexed_iterator1 to \c indexed_const_iterator1
+   */
+
     template<class C, class IC>
     class indexed_const_iterator1:
         public container_const_reference<C>, 
@@ -1711,6 +1901,22 @@ namespace boost { namespace numeric { namespace ublas {
     }
 #endif
 
+  /** \brief A class implementing an indexed random access iterator 
+   * of a matrix.
+   *
+   * \param C the mutable container type
+   * \param IC the iterator category
+   *
+   * This class implements a random access iterator. The current
+   * position is stored as two unsigned integers \c it1_ and \c it2_
+   * and the values are accessed via \c operator()(it1_, it2_) of the
+   * container. The iterator changes the second index.
+   *
+   * uBLAS extension: \c index1(), \c index2() and access to the
+   * dual iterator via \c begin(), \c end(), \c rbegin() and \c rend()
+   *
+   * Note: The container has to support the find1(rank, i, j) method
+   */
     template<class C, class IC>
     class indexed_iterator2:
         public container_reference<C>, 
@@ -1872,6 +2078,26 @@ namespace boost { namespace numeric { namespace ublas {
     }
 #endif
 
+  /** \brief A class implementing an indexed random access iterator 
+   * of a matrix.
+   *
+   * \param C the (immutable) container type
+   * \param IC the iterator category
+   *
+   * This class implements a random access iterator. The current
+   * position is stored as two unsigned integers \c it1_ and \c it2_
+   * and the values are accessed via \c operator()(it1_, it2_) of the
+   * container. The iterator changes the second index.
+   *
+   * uBLAS extension: \c index1(), \c index2() and access to the
+   * dual iterator via \c begin(), \c end(), \c rbegin() and \c rend()
+   *
+   * Note 1: The container has to support the \c find2(rank, i, j) method
+   *
+   * Note 2: there is an automatic conversion from 
+   * \c indexed_iterator2 to \c indexed_const_iterator2
+   */
+
     template<class C, class IC>
     class indexed_const_iterator2:
         public container_const_reference<C>,
@@ -2042,9 +2268,3 @@ namespace boost { namespace numeric { namespace ublas {
 }}}
 
 #endif
-
-
-
-
-
-
