@@ -50,26 +50,26 @@ namespace boost { namespace numeric { namespace ublas {
 #ifndef BOOST_UBLAS_NO_PROXY_SHORTCUTS
         BOOST_UBLAS_USING matrix_expression<symmetric_matrix<T, F1, F2, A> >::operator ();
 #endif
-        typedef std::size_t size_type;
-        typedef std::ptrdiff_t difference_type;
+        typedef typename A::size_type size_type;
+        typedef typename A::difference_type difference_type;
         typedef T value_type;
-        // typedef const T &const_reference;
-        typedef typename type_traits<T>::const_reference const_reference;
+        typedef const T &const_reference;
         typedef T &reference;
-        typedef const T *const_pointer;
+        typedef A array_type;
+    private:
         typedef T *pointer;
         typedef F1 functor1_type;
         typedef F2 functor2_type;
-        typedef A array_type;
-        typedef const A const_array_type;
-        typedef const symmetric_matrix<T, F1, F2, A> const_self_type;
         typedef symmetric_matrix<T, F1, F2, A> self_type;
+    public:
 #ifndef BOOST_UBLAS_CT_REFERENCE_BASE_TYPEDEFS
-        typedef const matrix_const_reference<const_self_type> const_closure_type;
+        typedef const matrix_const_reference<const self_type> const_closure_type;
 #else
-        typedef const matrix_reference<const_self_type> const_closure_type;
+        typedef const matrix_reference<const self_type> const_closure_type;
 #endif
         typedef matrix_reference<self_type> closure_type;
+        typedef vector<T, A> vector_temporary_type;
+        typedef matrix<T, F2, A> matrix_temporary_type;  // general sub-matrix
         typedef packed_tag storage_category;
         typedef typename F1::packed_category packed_category;
         typedef typename F2::orientation_category orientation_category;
@@ -82,14 +82,12 @@ namespace boost { namespace numeric { namespace ublas {
         BOOST_UBLAS_INLINE
         symmetric_matrix (size_type size):
             matrix_expression<self_type> (),
-            size_ (BOOST_UBLAS_SAME (size, size)), data_ (0) {
-            resize (size);
+            size_ (BOOST_UBLAS_SAME (size, size)), data_ (functor1_type::packed_size (size, size)) {
         }
         BOOST_UBLAS_INLINE
         symmetric_matrix (size_type size1, size_type size2):
             matrix_expression<self_type> (),
-            size_ (BOOST_UBLAS_SAME (size1, size2)), data_ (0) {
-            resize (size1, size2);
+            size_ (BOOST_UBLAS_SAME (size1, size2)), data_ (functor1_type::packed_size (size1, size2)) {
         }
         BOOST_UBLAS_INLINE
         symmetric_matrix (size_type size, const array_type &data):
@@ -103,12 +101,8 @@ namespace boost { namespace numeric { namespace ublas {
         BOOST_UBLAS_INLINE
         symmetric_matrix (const matrix_expression<AE> &ae):
             matrix_expression<self_type> (),
-            size_ (BOOST_UBLAS_SAME (ae ().size1 (), ae ().size2 ())), data_ (0) {
-#ifndef BOOST_UBLAS_TYPE_CHECK
-            resize (ae ().size1 (), ae ().size2 (), false);
-#else
-            resize (ae ().size1 (), ae ().size2 (), true);
-#endif
+            size_ (BOOST_UBLAS_SAME (ae ().size1 (), ae ().size2 ())),
+            data_ (functor1_type::packed_size (size_, size_)) {
             matrix_assign (scalar_assign<reference, BOOST_UBLAS_TYPENAME AE::value_type> (), *this, ae);
         }
 
@@ -122,7 +116,7 @@ namespace boost { namespace numeric { namespace ublas {
             return size_;
         }
         BOOST_UBLAS_INLINE
-        const_array_type &data () const {
+        const array_type &data () const {
             return data_;
         }
         BOOST_UBLAS_INLINE
@@ -133,13 +127,24 @@ namespace boost { namespace numeric { namespace ublas {
         // Resizing
         BOOST_UBLAS_INLINE
         void resize (size_type size, bool preserve = true) {
-            size_ = BOOST_UBLAS_SAME (size, size);
-            detail::resize (data (), functor1_type::packed_size (size, size), preserve);
+            size_ = size;
+            if (preserve) {
+                self_type temporary (size_, size_);
+                // FIXME use matrix_resize_preserve on conformant compilers
+                // detail::matrix_resize_reserve<functor_type> (*this, temporary, size_, size_);
+                assign_temporary (temporary);
+            }
+            else
+                data ().resize (functor1_type::packed_size (size_, size_));
         }
         BOOST_UBLAS_INLINE
         void resize (size_type size1, size_type size2, bool preserve = true) {
-            size_ = BOOST_UBLAS_SAME (size1, size2);
-            detail::resize (data (), functor1_type::packed_size (size1, size2), preserve);
+            resize (BOOST_UBLAS_SAME (size1, size2), preserve);
+        }
+        BOOST_UBLAS_INLINE
+        void resize_packed_preserve (size_type size) {
+            size_ = BOOST_UBLAS_SAME (size, size);
+            data ().resize (functor1_type::packed_size (size_, size_), value_type (0));
         }
 
         // Element access
@@ -165,8 +170,6 @@ namespace boost { namespace numeric { namespace ublas {
         // Assignment
         BOOST_UBLAS_INLINE
         symmetric_matrix &operator = (const symmetric_matrix &m) {
-            // Precondition for container relaxed as requested during review.
-            // BOOST_UBLAS_CHECK (size_ == m.size_, bad_size ());
             size_ = m.size_;
             data () = m.data ();
             return *this;
@@ -179,20 +182,9 @@ namespace boost { namespace numeric { namespace ublas {
         template<class AE>
         BOOST_UBLAS_INLINE
         symmetric_matrix &operator = (const matrix_expression<AE> &ae) {
-#ifdef BOOST_UBLAS_MUTABLE_TEMPORARY
-            return assign_temporary (self_type (ae));
-#else
             // return assign (self_type (ae));
             self_type temporary (ae);
             return assign_temporary (temporary);
-#endif
-        }
-        template<class AE>
-        BOOST_UBLAS_INLINE
-        symmetric_matrix &reset (const matrix_expression<AE> &ae) {
-            self_type temporary (ae);
-            resize (temporary.size1 (), temporary.size2 (), false);
-            return assign_temporary (temporary);
         }
         template<class AE>
         BOOST_UBLAS_INLINE
@@ -203,13 +195,9 @@ namespace boost { namespace numeric { namespace ublas {
         template<class AE>
         BOOST_UBLAS_INLINE
         symmetric_matrix& operator += (const matrix_expression<AE> &ae) {
-#ifdef BOOST_UBLAS_MUTABLE_TEMPORARY
-            return assign_temporary (self_type (*this + ae));
-#else
             // return assign (self_type (*this + ae));
             self_type temporary (*this + ae);
             return assign_temporary (temporary);
-#endif
         }
         template<class AE>
         BOOST_UBLAS_INLINE
@@ -220,18 +208,14 @@ namespace boost { namespace numeric { namespace ublas {
         template<class AE>
         BOOST_UBLAS_INLINE
         symmetric_matrix& operator -= (const matrix_expression<AE> &ae) {
-#ifdef BOOST_UBLAS_MUTABLE_TEMPORARY
-            return assign_temporary (self_type (*this - ae));
-#else
             // return assign (self_type (*this - ae));
             self_type temporary (*this - ae);
             return assign_temporary (temporary);
-#endif
         }
         template<class AE>
         BOOST_UBLAS_INLINE
-        symmetric_matrix &minus_assign (const matrix_expression<AE> &ae) { 
-            matrix_assign (scalar_minus_assign<reference, BOOST_UBLAS_TYPENAME AE::value_type> (), *this, ae); 
+        symmetric_matrix &minus_assign (const matrix_expression<AE> &ae) {
+            matrix_assign (scalar_minus_assign<reference, BOOST_UBLAS_TYPENAME AE::value_type> (), *this, ae);
             return *this;
         }
         template<class AT>
@@ -250,11 +234,7 @@ namespace boost { namespace numeric { namespace ublas {
         // Swapping
         BOOST_UBLAS_INLINE
         void swap (symmetric_matrix &m) {
-            // Too unusual semantic
-            // BOOST_UBLAS_CHECK (this != &m, external_logic ());
             if (this != &m) {
-                // Precondition for container relaxed as requested during review.
-                // BOOST_UBLAS_CHECK (size_ == m.size_, bad_size ());
                 std::swap (size_, m.size_);
                 data ().swap (m.data ());
             }
@@ -273,20 +253,15 @@ namespace boost { namespace numeric { namespace ublas {
         void insert (size_type i, size_type j, const_reference t) {
             BOOST_UBLAS_CHECK (i < size_, bad_index ());
             BOOST_UBLAS_CHECK (j < size_, bad_index ());
-// FIXME: is this ugly check still needed?!
-// #ifndef BOOST_UBLAS_USE_ET
-//             if (t == value_type ())
-//                 return;
-// #endif
             if (functor1_type::other (i, j)) {
                 size_type k = functor1_type::element (functor2_type (), i, size_, j, size_);
-                BOOST_UBLAS_CHECK (type_traits<value_type>::equals (data () [k], value_type ()) ||
+                BOOST_UBLAS_CHECK (type_traits<value_type>::equals (data () [k], value_type (0)) ||
                                    type_traits<value_type>::equals (data () [k], t), bad_index ());
                 // data ().insert (data ().begin () + k, t);
                 data () [k] = t;
             } else {
                 size_type k = functor1_type::element (functor2_type (), j, size_, i, size_);
-                BOOST_UBLAS_CHECK (type_traits<value_type>::equals (data () [k], value_type ()) ||
+                BOOST_UBLAS_CHECK (type_traits<value_type>::equals (data () [k], value_type (0)) ||
                                    type_traits<value_type>::equals (data () [k], t), bad_index ());
                 // data ().insert (data ().begin () + k, t);
                 data () [k] = t;
@@ -297,21 +272,21 @@ namespace boost { namespace numeric { namespace ublas {
             BOOST_UBLAS_CHECK (i < size_, bad_index ());
             BOOST_UBLAS_CHECK (j < size_, bad_index ());
             if (functor1_type::other (i, j)) {
-                size_type k = functor1_type::element (functor2_type (), i, size_, j, size_);
+                // size_type k = functor1_type::element (functor2_type (), i, size_, j, size_);
                 // data ().erase (data ().begin () + k));
-                data () [functor1_type::element (functor2_type (), i, size_, j, size_)] = value_type ();
+                data () [functor1_type::element (functor2_type (), i, size_, j, size_)] = value_type (0);
             } else {
-                size_type k = functor1_type::element (functor2_type (), j, size_, i, size_);
                 // data ().erase (data ().begin () + k);
-                data () [k] = value_type ();
+                data () [functor1_type::element (functor2_type (), j, size_, i, size_)] = value_type (0);
             }
         }
         BOOST_UBLAS_INLINE
         void clear () {
             // data ().clear ();
-            std::fill (data ().begin (), data ().end (), value_type ());
+            std::fill (data ().begin (), data ().end (), value_type (0));
         }
 
+        // Iterator types
 #ifdef BOOST_UBLAS_USE_INDEXED_ITERATOR
         typedef indexed_iterator1<self_type, packed_random_access_iterator_tag> iterator1;
         typedef indexed_iterator2<self_type, packed_random_access_iterator_tag> iterator2;
@@ -369,10 +344,10 @@ namespace boost { namespace numeric { namespace ublas {
 #ifdef BOOST_MSVC_STD_ITERATOR
             typedef const_reference reference;
 #else
-            typedef typename symmetric_matrix::difference_type difference_type;
             typedef typename symmetric_matrix::value_type value_type;
+            typedef typename symmetric_matrix::difference_type difference_type;
             typedef typename symmetric_matrix::const_reference reference;
-            typedef typename symmetric_matrix::const_pointer pointer;
+            typedef const typename symmetric_matrix::pointer pointer;
 #endif
             typedef const_iterator2 dual_iterator_type;
             typedef const_reverse_iterator2 dual_reverse_iterator_type;
@@ -418,7 +393,7 @@ namespace boost { namespace numeric { namespace ublas {
 
             // Dereference
             BOOST_UBLAS_INLINE
-            reference operator * () const {
+            const_reference operator * () const {
                 return (*this) () (it1_, it2_);
             }
 
@@ -509,8 +484,8 @@ namespace boost { namespace numeric { namespace ublas {
         public:
             typedef packed_random_access_iterator_tag iterator_category;
 #ifndef BOOST_MSVC_STD_ITERATOR
-            typedef typename symmetric_matrix::difference_type difference_type;
             typedef typename symmetric_matrix::value_type value_type;
+            typedef typename symmetric_matrix::difference_type difference_type;
             typedef typename symmetric_matrix::reference reference;
             typedef typename symmetric_matrix::pointer pointer;
 #endif
@@ -600,7 +575,7 @@ namespace boost { namespace numeric { namespace ublas {
                 return it2_;
             }
 
-            // Assignment 
+            // Assignment
             BOOST_UBLAS_INLINE
             iterator1 &operator = (const iterator1 &it) {
                 container_reference<self_type>::assign (&it ());
@@ -650,10 +625,10 @@ namespace boost { namespace numeric { namespace ublas {
 #ifdef BOOST_MSVC_STD_ITERATOR
             typedef const_reference reference;
 #else
-            typedef typename symmetric_matrix::difference_type difference_type;
             typedef typename symmetric_matrix::value_type value_type;
+            typedef typename symmetric_matrix::difference_type difference_type;
             typedef typename symmetric_matrix::const_reference reference;
-            typedef typename symmetric_matrix::const_pointer pointer;
+            typedef const typename symmetric_matrix::pointer pointer;
 #endif
             typedef const_iterator1 dual_iterator_type;
             typedef const_reverse_iterator1 dual_reverse_iterator_type;
@@ -699,7 +674,7 @@ namespace boost { namespace numeric { namespace ublas {
 
             // Dereference
             BOOST_UBLAS_INLINE
-            reference operator * () const {
+            const_reference operator * () const {
                 return (*this) () (it1_, it2_);
             }
 
@@ -744,7 +719,7 @@ namespace boost { namespace numeric { namespace ublas {
                 return it2_;
             }
 
-            // Assignment 
+            // Assignment
             BOOST_UBLAS_INLINE
             const_iterator2 &operator = (const const_iterator2 &it) {
                 container_const_reference<self_type>::assign (&it ());
@@ -790,8 +765,8 @@ namespace boost { namespace numeric { namespace ublas {
         public:
             typedef packed_random_access_iterator_tag iterator_category;
 #ifndef BOOST_MSVC_STD_ITERATOR
-            typedef typename symmetric_matrix::difference_type difference_type;
             typedef typename symmetric_matrix::value_type value_type;
+            typedef typename symmetric_matrix::difference_type difference_type;
             typedef typename symmetric_matrix::reference reference;
             typedef typename symmetric_matrix::pointer pointer;
 #endif
@@ -881,7 +856,7 @@ namespace boost { namespace numeric { namespace ublas {
                 return it2_;
             }
 
-            // Assignment 
+            // Assignment
             BOOST_UBLAS_INLINE
             iterator2 &operator = (const iterator2 &it) {
                 container_reference<self_type>::assign (&it ());
@@ -981,44 +956,26 @@ namespace boost { namespace numeric { namespace ublas {
 #ifndef BOOST_UBLAS_CT_PROXY_BASE_TYPEDEFS
         typedef typename M::const_reference const_reference;
         typedef typename M::reference reference;
-        typedef typename M::const_pointer const_pointer;
-        typedef typename M::pointer pointer;
 #else
         typedef typename M::const_reference const_reference;
-        typedef typename boost::mpl::if_c<boost::is_const<M>::value,
+        typedef typename boost::mpl::if_<boost::is_const<M>,
                                           typename M::const_reference,
                                           typename M::reference>::type reference;
-        typedef typename M::const_pointer const_pointer;
-        typedef typename boost::mpl::if_c<boost::is_const<M>::value,
-                                          typename M::const_pointer,
-                                          typename M::pointer>::type pointer;
 #endif
 #ifndef BOOST_UBLAS_CT_PROXY_CLOSURE_TYPEDEFS
         typedef typename M::closure_type matrix_closure_type;
 #else
-        typedef typename boost::mpl::if_c<boost::is_const<M>::value,
+        typedef typename boost::mpl::if_<boost::is_const<M>,
                                           typename M::const_closure_type,
                                           typename M::closure_type>::type matrix_closure_type;
 #endif
-        typedef const symmetric_adaptor<M, F> const_self_type;
+    private:
         typedef symmetric_adaptor<M, F> self_type;
-        typedef const_self_type const_closure_type;
+    public:
+        typedef const self_type const_closure_type;
         typedef self_type closure_type;
-#ifndef BOOST_UBLAS_CT_PROXY_BASE_TYPEDEFS
-        typedef typename M::const_iterator1 const_iterator1_type;
-        typedef typename M::iterator1 iterator1_type;
-        typedef typename M::const_iterator2 const_iterator2_type;
-        typedef typename M::iterator2 iterator2_type;
-#else
-        typedef typename M::const_iterator1 const_iterator1_type;
-        typedef typename boost::mpl::if_c<boost::is_const<M>::value,
-                                          typename M::const_iterator1,
-                                          typename M::iterator1>::type iterator1_type;
-        typedef typename M::const_iterator2 const_iterator2_type;
-        typedef typename boost::mpl::if_c<boost::is_const<M>::value,
-                                          typename M::const_iterator2,
-                                          typename M::iterator2>::type iterator2_type;
-#endif
+        typedef typename M::vector_temporary_type vector_temporary_type;
+        typedef typename M::matrix_temporary_type matrix_temporary_type;
         typedef typename storage_restrict_traits<typename M::storage_category,
                                                  packed_proxy_tag>::storage_category storage_category;
         typedef typename F::packed_category packed_category;
@@ -1062,18 +1019,6 @@ namespace boost { namespace numeric { namespace ublas {
             return data_;
         }
 
-#ifdef BOOST_UBLAS_DEPRECATED
-        // Resetting
-        BOOST_UBLAS_INLINE
-        void reset (matrix_type &data) {
-            BOOST_UBLAS_CHECK (data.size1 () == data.size2 (), bad_size ());
-            // References are not retargetable.
-            // Thanks to Michael Stevens for spotting this.
-            // data_ = data;
-            data_.reset (data);
-        }
-#endif
-
         // Element access
 #ifndef BOOST_UBLAS_PROXY_CONST_MEMBER
         BOOST_UBLAS_INLINE
@@ -1109,7 +1054,7 @@ namespace boost { namespace numeric { namespace ublas {
         // Assignment
         BOOST_UBLAS_INLINE
         symmetric_adaptor &operator = (const symmetric_adaptor &m) {
-            matrix_assign (scalar_assign<reference, value_type> (), *this, m, functor_type ());
+            matrix_assign (scalar_assign<BOOST_UBLAS_TYPENAME iterator1_type::reference, value_type> (), functor_type (), *this, m);
             return *this;
         }
         BOOST_UBLAS_INLINE
@@ -1120,64 +1065,63 @@ namespace boost { namespace numeric { namespace ublas {
         template<class AE>
         BOOST_UBLAS_INLINE
         symmetric_adaptor &operator = (const matrix_expression<AE> &ae) {
-            matrix_assign (scalar_assign<reference, value_type> (), *this, matrix<value_type> (ae), functor_type ());
+            matrix_assign (scalar_assign<BOOST_UBLAS_TYPENAME iterator1_type::reference, value_type> (), functor_type (), *this, matrix<value_type> (ae));
             return *this;
         }
         template<class AE>
         BOOST_UBLAS_INLINE
         symmetric_adaptor &assign (const matrix_expression<AE> &ae) {
-            matrix_assign (scalar_assign<reference, BOOST_UBLAS_TYPENAME AE::value_type> (), *this, ae, functor_type ());
+            matrix_assign (scalar_assign<BOOST_UBLAS_TYPENAME iterator1_type::reference, BOOST_UBLAS_TYPENAME AE::value_type> (), functor_type (), *this, ae);
             return *this;
         }
         template<class AE>
         BOOST_UBLAS_INLINE
         symmetric_adaptor& operator += (const matrix_expression<AE> &ae) {
-            matrix_assign (scalar_assign<reference, value_type> (), *this, matrix<value_type> (*this + ae), functor_type ()); 
+            matrix_assign (scalar_assign<BOOST_UBLAS_TYPENAME iterator1_type::reference, value_type> (), functor_type (), *this, matrix<value_type> (*this + ae));
             return *this;
         }
         template<class AE>
         BOOST_UBLAS_INLINE
-        symmetric_adaptor &plus_assign (const matrix_expression<AE> &ae) { 
-            matrix_assign (scalar_plus_assign<reference, BOOST_UBLAS_TYPENAME AE::value_type> (), *this, ae, functor_type ());
+        symmetric_adaptor &plus_assign (const matrix_expression<AE> &ae) {
+            matrix_assign (scalar_plus_assign<BOOST_UBLAS_TYPENAME iterator1_type::reference, BOOST_UBLAS_TYPENAME AE::value_type> (), functor_type (), *this, ae);
             return *this;
         }
         template<class AE>
         BOOST_UBLAS_INLINE
         symmetric_adaptor& operator -= (const matrix_expression<AE> &ae) {
-            matrix_assign (scalar_assign<reference, value_type> (), *this, matrix<value_type> (*this - ae), functor_type ()); 
+            matrix_assign (scalar_assign<BOOST_UBLAS_TYPENAME iterator1_type::reference, value_type> (), functor_type (), *this, matrix<value_type> (*this - ae));
             return *this;
         }
         template<class AE>
         BOOST_UBLAS_INLINE
         symmetric_adaptor &minus_assign (const matrix_expression<AE> &ae) {
-            matrix_assign (scalar_minus_assign<reference, BOOST_UBLAS_TYPENAME AE::value_type> (), *this, ae, functor_type ()); 
+            matrix_assign (scalar_minus_assign<BOOST_UBLAS_TYPENAME iterator1_type::reference, BOOST_UBLAS_TYPENAME AE::value_type> (), functor_type (), *this, ae);
             return *this;
         }
         template<class AT>
         BOOST_UBLAS_INLINE
         symmetric_adaptor& operator *= (const AT &at) {
-            matrix_assign_scalar (scalar_multiplies_assign<reference, AT> (), *this, at);
+            matrix_assign_scalar (scalar_multiplies_assign<BOOST_UBLAS_TYPENAME iterator1_type::reference, AT> (), *this, at);
             return *this;
         }
         template<class AT>
         BOOST_UBLAS_INLINE
         symmetric_adaptor& operator /= (const AT &at) {
-            matrix_assign_scalar (scalar_divides_assign<reference, AT> (), *this, at);
+            matrix_assign_scalar (scalar_divides_assign<BOOST_UBLAS_TYPENAME iterator1_type::reference, AT> (), *this, at);
             return *this;
         }
 
-        // Comparison
-        bool operator == (const symmetric_adaptor &sa) const {
-            return (*this).data () == sa.data ();
-        }
+        // Closure comparison
+        BOOST_UBLAS_INLINE
+        bool same_closure (const symmetric_adaptor &sa) const {
+            return (*this).data ().same_closure (sa.data ());
+       }
 
         // Swapping
         BOOST_UBLAS_INLINE
         void swap (symmetric_adaptor &m) {
-            // Too unusual semantic
-            // BOOST_UBLAS_CHECK (this != &m, external_logic ());
             if (this != &m)
-                matrix_swap (scalar_swap<reference, reference> (), *this, m, functor_type ());
+                matrix_swap (scalar_swap<BOOST_UBLAS_TYPENAME iterator1_type::reference, BOOST_UBLAS_TYPENAME iterator1_type::reference> (), functor_type (), *this, m);
         }
 #ifndef BOOST_UBLAS_NO_MEMBER_FRIENDS
         BOOST_UBLAS_INLINE
@@ -1186,6 +1130,26 @@ namespace boost { namespace numeric { namespace ublas {
         }
 #endif
 
+        // Iterator types
+    private:
+        // Use matrix iterator
+#ifndef BOOST_UBLAS_CT_PROXY_BASE_TYPEDEFS
+        typedef typename M::const_iterator1 const_iterator1_type;
+        typedef typename M::iterator1 iterator1_type;
+        typedef typename M::const_iterator2 const_iterator2_type;
+        typedef typename M::iterator2 iterator2_type;
+#else
+        typedef typename M::const_iterator1 const_iterator1_type;
+        typedef typename boost::mpl::if_<boost::is_const<M>,
+                                          typename M::const_iterator1,
+                                          typename M::iterator1>::type iterator1_type;
+        typedef typename M::const_iterator2 const_iterator2_type;
+        typedef typename boost::mpl::if_<boost::is_const<M>,
+                                          typename M::const_iterator2,
+                                          typename M::iterator2>::type iterator2_type;
+#endif
+
+    public:
 #ifdef BOOST_UBLAS_USE_INDEXED_ITERATOR
         typedef indexed_iterator1<self_type, packed_random_access_iterator_tag> iterator1;
         typedef indexed_iterator2<self_type, packed_random_access_iterator_tag> iterator2;
@@ -1282,8 +1246,8 @@ namespace boost { namespace numeric { namespace ublas {
 #ifndef BOOST_MSVC_STD_ITERATOR
             typedef typename iterator_restrict_traits<typename const_iterator1_type::iterator_category,
                                                       dense_random_access_iterator_tag>::iterator_category iterator_category;
-            typedef typename const_iterator1_type::difference_type difference_type;
             typedef typename const_iterator1_type::value_type value_type;
+            typedef typename const_iterator1_type::difference_type difference_type;
             typedef typename const_iterator1_type::reference reference;
             typedef typename const_iterator1_type::pointer pointer;
 #else
@@ -1320,6 +1284,8 @@ namespace boost { namespace numeric { namespace ublas {
                                    (current_ == 0 && it1_ != it1_end_) ||
                                    (current_ == 1 && it2_ != it2_end_), internal_logic ());
             }
+            // FIXME cannot compile
+            //  iterator1 does not have these members!
             BOOST_UBLAS_INLINE
             const_iterator1 (const iterator1 &it):
                 container_const_reference<self_type> (it ()),
@@ -1380,23 +1346,23 @@ namespace boost { namespace numeric { namespace ublas {
             const_iterator1 &operator += (difference_type n) {
                 BOOST_UBLAS_CHECK (current_ == 0 || current_ == 1, internal_logic ());
                 if (current_ == 0) {
-                    size_type d = std::min (n, it1_end_ - it1_);
+                    size_type d = (std::min) (n, it1_end_ - it1_);
                     it1_ += d;
                     n -= d;
                     if (n > 0 || (end_ == 1 && it1_ == it1_end_)) {
                         BOOST_UBLAS_CHECK (end_ == 1, external_logic ());
-                        d = std::min (n, it2_end_ - it2_begin_);
+                        d = (std::min) (n, it2_end_ - it2_begin_);
                         it2_ = it2_begin_ + d;
                         n -= d;
                         current_ = 1;
                     }
                 } else /* if (current_ == 1) */ {
-                    size_type d = std::min (n, it2_end_ - it2_);
+                    size_type d = (std::min) (n, it2_end_ - it2_);
                     it2_ += d;
                     n -= d;
                     if (n > 0 || (end_ == 0 && it2_ == it2_end_)) {
                         BOOST_UBLAS_CHECK (end_ == 0, external_logic ());
-                        d = std::min (n, it1_end_ - it1_begin_);
+                        d = (std::min) (n, it1_end_ - it1_begin_);
                         it1_ = it1_begin_ + d;
                         n -= d;
                         current_ = 0;
@@ -1409,23 +1375,23 @@ namespace boost { namespace numeric { namespace ublas {
             const_iterator1 &operator -= (difference_type n) {
                 BOOST_UBLAS_CHECK (current_ == 0 || current_ == 1, internal_logic ());
                 if (current_ == 0) {
-                    size_type d = std::min (n, it1_ - it1_begin_);
+                    size_type d = (std::min) (n, it1_ - it1_begin_);
                     it1_ -= d;
                     n -= d;
                     if (n > 0) {
                         BOOST_UBLAS_CHECK (end_ == 1, external_logic ());
-                        d = std::min (n, it2_end_ - it2_begin_);
+                        d = (std::min) (n, it2_end_ - it2_begin_);
                         it2_ = it2_end_ - d;
                         n -= d;
                         current_ = 1;
                     }
                 } else /* if (current_ == 1) */ {
-                    size_type d = std::min (n, it2_ - it2_begin_);
+                    size_type d = (std::min) (n, it2_ - it2_begin_);
                     it2_ -= d;
                     n -= d;
                     if (n > 0) {
                         BOOST_UBLAS_CHECK (end_ == 0, external_logic ());
-                        d = std::min (n, it1_end_ - it1_begin_);
+                        d = (std::min) (n, it1_end_ - it1_begin_);
                         it1_ = it1_end_ - d;
                         n -= d;
                         current_ = 0;
@@ -1462,7 +1428,7 @@ namespace boost { namespace numeric { namespace ublas {
 
             // Dereference
             BOOST_UBLAS_INLINE
-            reference operator * () const {
+            const_reference operator * () const {
                 BOOST_UBLAS_CHECK (current_ == 0 || current_ == 1, internal_logic ());
                 if (current_ == 0) {
                     BOOST_UBLAS_CHECK (it1_ != it1_end_, internal_logic ());
@@ -1591,8 +1557,8 @@ namespace boost { namespace numeric { namespace ublas {
 #ifndef BOOST_MSVC_STD_ITERATOR
             typedef typename iterator_restrict_traits<typename iterator1_type::iterator_category,
                                                       packed_random_access_iterator_tag>::iterator_category iterator_category;
-            typedef typename iterator1_type::difference_type difference_type;
             typedef typename iterator1_type::value_type value_type;
+            typedef typename iterator1_type::difference_type difference_type;
             typedef typename iterator1_type::reference reference;
             typedef typename iterator1_type::pointer pointer;
 #else
@@ -1729,8 +1695,8 @@ namespace boost { namespace numeric { namespace ublas {
 #ifndef BOOST_MSVC_STD_ITERATOR
             typedef typename iterator_restrict_traits<typename const_iterator2_type::iterator_category,
                                                       dense_random_access_iterator_tag>::iterator_category iterator_category;
-            typedef typename const_iterator2_type::difference_type difference_type;
             typedef typename const_iterator2_type::value_type value_type;
+            typedef typename const_iterator2_type::difference_type difference_type;
             typedef typename const_iterator2_type::reference reference;
             typedef typename const_iterator2_type::pointer pointer;
 #else
@@ -1767,6 +1733,8 @@ namespace boost { namespace numeric { namespace ublas {
                                    (current_ == 0 && it1_ != it1_end_) ||
                                    (current_ == 1 && it2_ != it2_end_), internal_logic ());
             }
+            // FIXME cannot compiler
+            //  iterator2 does not have these members!
             BOOST_UBLAS_INLINE
             const_iterator2 (const iterator2 &it):
                 container_const_reference<self_type> (it ()),
@@ -1827,23 +1795,23 @@ namespace boost { namespace numeric { namespace ublas {
             const_iterator2 &operator += (difference_type n) {
                 BOOST_UBLAS_CHECK (current_ == 0 || current_ == 1, internal_logic ());
                 if (current_ == 0) {
-                    size_type d = std::min (n, it1_end_ - it1_);
+                    size_type d = (std::min) (n, it1_end_ - it1_);
                     it1_ += d;
                     n -= d;
                     if (n > 0 || (end_ == 1 && it1_ == it1_end_)) {
                         BOOST_UBLAS_CHECK (end_ == 1, external_logic ());
-                        d = std::min (n, it2_end_ - it2_begin_);
+                        d = (std::min) (n, it2_end_ - it2_begin_);
                         it2_ = it2_begin_ + d;
                         n -= d;
                         current_ = 1;
                     }
                 } else /* if (current_ == 1) */ {
-                    size_type d = std::min (n, it2_end_ - it2_);
+                    size_type d = (std::min) (n, it2_end_ - it2_);
                     it2_ += d;
                     n -= d;
                     if (n > 0 || (end_ == 0 && it2_ == it2_end_)) {
                         BOOST_UBLAS_CHECK (end_ == 0, external_logic ());
-                        d = std::min (n, it1_end_ - it1_begin_);
+                        d = (std::min) (n, it1_end_ - it1_begin_);
                         it1_ = it1_begin_ + d;
                         n -= d;
                         current_ = 0;
@@ -1856,23 +1824,23 @@ namespace boost { namespace numeric { namespace ublas {
             const_iterator2 &operator -= (difference_type n) {
                 BOOST_UBLAS_CHECK (current_ == 0 || current_ == 1, internal_logic ());
                 if (current_ == 0) {
-                    size_type d = std::min (n, it1_ - it1_begin_);
+                    size_type d = (std::min) (n, it1_ - it1_begin_);
                     it1_ -= d;
                     n -= d;
                     if (n > 0) {
                         BOOST_UBLAS_CHECK (end_ == 1, external_logic ());
-                        d = std::min (n, it2_end_ - it2_begin_);
+                        d = (std::min) (n, it2_end_ - it2_begin_);
                         it2_ = it2_end_ - d;
                         n -= d;
                         current_ = 1;
                     }
                 } else /* if (current_ == 1) */ {
-                    size_type d = std::min (n, it2_ - it2_begin_);
+                    size_type d = (std::min) (n, it2_ - it2_begin_);
                     it2_ -= d;
                     n -= d;
                     if (n > 0) {
                         BOOST_UBLAS_CHECK (end_ == 0, external_logic ());
-                        d = std::min (n, it1_end_ - it1_begin_);
+                        d = (std::min) (n, it1_end_ - it1_begin_);
                         it1_ = it1_end_ - d;
                         n -= d;
                         current_ = 0;
@@ -1909,7 +1877,7 @@ namespace boost { namespace numeric { namespace ublas {
 
             // Dereference
             BOOST_UBLAS_INLINE
-            reference operator * () const {
+            const_reference operator * () const {
                 BOOST_UBLAS_CHECK (current_ == 0 || current_ == 1, internal_logic ());
                 if (current_ == 0) {
                     BOOST_UBLAS_CHECK (it1_ != it1_end_, internal_logic ());
@@ -2038,8 +2006,8 @@ namespace boost { namespace numeric { namespace ublas {
 #ifndef BOOST_MSVC_STD_ITERATOR
             typedef typename iterator_restrict_traits<typename iterator2_type::iterator_category,
                                                       packed_random_access_iterator_tag>::iterator_category iterator_category;
-            typedef typename iterator2_type::difference_type difference_type;
             typedef typename iterator2_type::value_type value_type;
+            typedef typename iterator2_type::difference_type difference_type;
             typedef typename iterator2_type::reference reference;
             typedef typename iterator2_type::pointer pointer;
 #else
@@ -2211,12 +2179,13 @@ namespace boost { namespace numeric { namespace ublas {
     };
 
     template<class M, class F>
-    typename symmetric_adaptor<M, F>::matrix_type symmetric_adaptor<M, F>::nil_;
+    typename symmetric_adaptor<M, F>::matrix_type symmetric_adaptor<M, F>::nil_
+#ifdef BOOST_UBLAS_STATIC_OLD_INIT
+        = BOOST_UBLAS_TYPENAME symmetric_adaptor<M, F>::matrix_type ():
+#endif
+    ;
+
 
 }}}
 
 #endif
-
-
-
-
