@@ -1,19 +1,19 @@
-//  (C) Copyright Gennadiy Rozental 2001-2003.
-//  Use, modification, and distribution are subject to the 
-//  Boost Software License, Version 1.0. (See accompanying file 
-//  LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
+//  (C) Copyright Gennadiy Rozental 2001-2004.
+//  Distributed under the Boost Software License, Version 1.0.
+//  (See accompanying file LICENSE_1_0.txt or copy at 
+//  http://www.boost.org/LICENSE_1_0.txt)
 
 //  See http://www.boost.org/libs/test for the library home page.
 //
 //  File        : $RCSfile: prg_exec_monitor.hpp,v $
 //
-//  Version     : $Revision: 1.5 $
+//  Version     : $Revision: 1.7 $
 //
 //  Description : included (vs. linked ) version of Program Execution Monitor
 // ***************************************************************************
 
-#ifndef BOOST_INCLUDED_PRG_EXEC_MONITOR_HPP
-#define BOOST_INCLUDED_PRG_EXEC_MONITOR_HPP
+#ifndef BOOST_INCLUDED_PRG_EXEC_MONITOR_HPP_071894GER
+#define BOOST_INCLUDED_PRG_EXEC_MONITOR_HPP_071894GER
 
 #include <libs/test/src/execution_monitor.cpp>
 
@@ -23,10 +23,15 @@
 //  Revision History :
 //  
 //  $Log: prg_exec_monitor.hpp,v $
+//  Revision 1.7  2004/07/19 12:30:49  rogeeff
+//  guard rename
+//
+//  Revision 1.6  2004/05/21 06:19:35  rogeeff
+//  licence update
+//
 //  Revision 1.5  2003/12/01 00:41:56  rogeeff
 //  prerelease cleaning
 //
-
 // ***************************************************************************
 
-#endif // BOOST_INCLUDED_PRG_EXEC_MONITOR_HPP
+#endif // BOOST_INCLUDED_PRG_EXEC_MONITOR_HPP_071894GER
