@@ -1,20 +1,20 @@
-//  (C) Copyright Gennadiy Rozental 2001-2003.
+//  (C) Copyright Gennadiy Rozental 2001-2004.
 //  (C) Copyright Ullrich Koethe 2001.
-//  Use, modification, and distribution are subject to the 
-//  Boost Software License, Version 1.0. (See accompanying file 
-//  LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
+//  Distributed under the Boost Software License, Version 1.0.
+//  (See accompanying file LICENSE_1_0.txt or copy at 
+//  http://www.boost.org/LICENSE_1_0.txt)
 
 //  See http://www.boost.org/libs/test for the library home page.
 //
 //  File        : $RCSfile: test_tools.hpp,v $
 //
-//  Version     : $Revision: 1.35.2.1 $
+//  Version     : $Revision: 1.45 $
 //
 //  Description : contains definition for all test tools in test toolbox
 // ***************************************************************************
 
-#ifndef BOOST_TEST_TOOLS_HPP
-#define BOOST_TEST_TOOLS_HPP
+#ifndef BOOST_TEST_TOOLS_HPP_071894GER
+#define BOOST_TEST_TOOLS_HPP_071894GER
 
 // Boost.Test
 #include <boost/test/detail/unit_test_config.hpp>
@@ -32,75 +32,79 @@
 #include <memory>           // for std::auto_ptr
 #include <string>           // for std::string
 
+#include <boost/test/detail/suppress_warnings.hpp>
+
 // ************************************************************************** //
 // **************                    TOOL BOX                  ************** //
 // ************************************************************************** //
 
-#define BOOST_CHECKPOINT(message_)                                          \
-    boost::test_toolbox::detail::checkpoint_impl(                           \
-        boost::wrap_stringstream().ref() << message_, __FILE__, __LINE__)   \
+#define BOOST_CHECKPOINT(message_) \
+    boost::test_tools::tt_detail::checkpoint_impl( \
+        boost::wrap_stringstream().ref() << message_, BOOST_TEST_STRING_LITERAL(__FILE__), (std::size_t)__LINE__)   \
 /**/
 
-#define BOOST_WARN(predicate)                                               \
-    boost::test_toolbox::detail::warn_and_continue_impl((predicate),        \
-        boost::wrap_stringstream().ref() << #predicate, __FILE__, __LINE__) \
+#define BOOST_WARN(predicate) \
+    boost::test_tools::tt_detail::warn_and_continue_impl((predicate), \
+        boost::wrap_stringstream().ref() << #predicate, BOOST_TEST_STRING_LITERAL(__FILE__), (std::size_t)__LINE__) \
 /**/
 
-#define BOOST_CHECK(predicate)                                              \
-    boost::test_toolbox::detail::test_and_continue_impl((predicate),        \
-        boost::wrap_stringstream().ref() << #predicate, __FILE__, __LINE__) \
+#define BOOST_CHECK(predicate) \
+    boost::test_tools::tt_detail::test_and_continue_impl((predicate), \
+        boost::wrap_stringstream().ref() << #predicate, BOOST_TEST_STRING_LITERAL(__FILE__), (std::size_t)__LINE__) \
 /**/
 
-#define BOOST_CHECK_EQUAL(left_, right_)                                                \
-    boost::test_toolbox::detail::equal_and_continue_impl((left_), (right_),             \
-        boost::wrap_stringstream().ref() << #left_ " == " #right_, __FILE__, __LINE__)
+#define BOOST_CHECK_EQUAL(left_, right_) \
+    boost::test_tools::tt_detail::equal_and_continue_impl((left_), (right_), \
+        boost::wrap_stringstream().ref() << #left_ " == " #right_, BOOST_TEST_STRING_LITERAL(__FILE__), (std::size_t)__LINE__)
 /**/
 
 #define BOOST_CHECK_CLOSE(left_, right_, tolerance) \
-    boost::test_toolbox::detail::compare_and_continue_impl((left_), (right_), (tolerance),\
-                                                           #left_,  #right_, __FILE__, __LINE__)
+    boost::test_tools::tt_detail::compare_and_continue_impl((left_), (right_), (tolerance), \
+                                                          BOOST_TEST_STRING_LITERAL( #left_ ), \
+                                                          BOOST_TEST_STRING_LITERAL( #right_ ), \
+                                                          BOOST_TEST_STRING_LITERAL(__FILE__), (std::size_t)__LINE__) \
 /**/
 
 #define BOOST_BITWISE_EQUAL(left_, right_) \
-    boost::test_toolbox::detail::bitwise_equal_and_continue_impl((left_), (right_), \
-        boost::wrap_stringstream().ref() << #left_ " =.= " #right_, __FILE__, __LINE__)
+    boost::test_tools::tt_detail::bitwise_equal_and_continue_impl((left_), (right_), \
+        boost::wrap_stringstream().ref() << #left_ " =.= " #right_, BOOST_TEST_STRING_LITERAL(__FILE__), (std::size_t)__LINE__)
 /**/
 
 #define BOOST_REQUIRE(predicate) \
-    boost::test_toolbox::detail::test_and_throw_impl((predicate), \
-        boost::wrap_stringstream().ref() << #predicate, __FILE__, __LINE__)
+    boost::test_tools::tt_detail::test_and_throw_impl((predicate), \
+        boost::wrap_stringstream().ref() << #predicate, BOOST_TEST_STRING_LITERAL(__FILE__), (std::size_t)__LINE__)
 /**/
 
 #define BOOST_MESSAGE(message_) \
-    boost::test_toolbox::detail::message_impl( \
-        boost::wrap_stringstream().ref() << message_, __FILE__, __LINE__)
+    boost::test_tools::tt_detail::message_impl( \
+        boost::wrap_stringstream().ref() << message_, BOOST_TEST_STRING_LITERAL(__FILE__), (std::size_t)__LINE__)
 /**/
 
 #define BOOST_WARN_MESSAGE(predicate, message_) \
-    boost::test_toolbox::detail::warn_and_continue_impl((predicate), \
-        boost::wrap_stringstream().ref() << message_, __FILE__, __LINE__,false)
+    boost::test_tools::tt_detail::warn_and_continue_impl((predicate), \
+        boost::wrap_stringstream().ref() << message_, BOOST_TEST_STRING_LITERAL(__FILE__), (std::size_t)__LINE__,false)
 /**/
 
 #define BOOST_CHECK_MESSAGE(predicate, message_) \
-    boost::test_toolbox::detail::test_and_continue_impl((predicate), \
-        boost::wrap_stringstream().ref() << message_, __FILE__, __LINE__,false)
+    boost::test_tools::tt_detail::test_and_continue_impl((predicate), \
+        boost::wrap_stringstream().ref() << message_, BOOST_TEST_STRING_LITERAL(__FILE__), (std::size_t)__LINE__,false)
 /**/
 
 #define BOOST_REQUIRE_MESSAGE(predicate, message_) \
-    boost::test_toolbox::detail::test_and_throw_impl((predicate), \
-        boost::wrap_stringstream().ref() << message_, __FILE__, __LINE__,false)
+    boost::test_tools::tt_detail::test_and_throw_impl((predicate), \
+        boost::wrap_stringstream().ref() << message_, BOOST_TEST_STRING_LITERAL(__FILE__), (std::size_t)__LINE__,false)
 /**/
 
 #define BOOST_CHECK_PREDICATE( predicate, arg_list_size, arg_list ) \
-    boost::test_toolbox::detail::test_and_continue_impl(predicate, BOOST_PLACE_PREDICATE_ARGS ## arg_list_size arg_list, \
+    boost::test_tools::tt_detail::test_and_continue_impl(predicate, BOOST_PLACE_PREDICATE_ARGS ## arg_list_size arg_list, \
         boost::wrap_stringstream().ref() << #predicate << "("\
-        << BOOST_PRINT_PREDICATE_ARGS ## arg_list_size arg_list << ")", __FILE__, __LINE__)
+            << BOOST_PRINT_PREDICATE_ARGS ## arg_list_size arg_list << ")", BOOST_TEST_STRING_LITERAL(__FILE__), (std::size_t)__LINE__)
 /**/
 
 #define BOOST_REQUIRE_PREDICATE( predicate, arg_list_size, arg_list ) \
-    boost::test_toolbox::detail::test_and_throw_impl(predicate, BOOST_PLACE_PREDICATE_ARGS ## arg_list_size arg_list, \
+    boost::test_tools::tt_detail::test_and_throw_impl(predicate, BOOST_PLACE_PREDICATE_ARGS ## arg_list_size arg_list, \
         boost::wrap_stringstream().ref() << #predicate << "("\
-        << BOOST_PRINT_PREDICATE_ARGS ## arg_list_size arg_list << ")", __FILE__, __LINE__)
+            << BOOST_PRINT_PREDICATE_ARGS ## arg_list_size arg_list << ")", BOOST_TEST_STRING_LITERAL(__FILE__), (std::size_t)__LINE__)
 /**/
 
 #define BOOST_ERROR(message_) BOOST_CHECK_MESSAGE( false, message_ )
@@ -131,12 +135,12 @@
 /**/
 
 #define BOOST_CHECK_EQUAL_COLLECTIONS( left_begin_, left_end_, right_begin_ ) \
-    boost::test_toolbox::detail::equal_and_continue_impl( (left_begin_), (left_end_), (right_begin_),\
+    boost::test_tools::tt_detail::equal_and_continue_impl( (left_begin_), (left_end_), (right_begin_),\
         boost::wrap_stringstream().ref() << \
-            "{" #left_begin_ ", " #left_end_ "}" " == {" #right_begin_ ", ...}", __FILE__, __LINE__)
+            "{" #left_begin_ ", " #left_end_ "}" " == {" #right_begin_ ", ...}", BOOST_TEST_STRING_LITERAL(__FILE__), (std::size_t)__LINE__)
 /**/
 
-#define BOOST_IS_DEFINED(symb) boost::test_toolbox::detail::is_defined_impl( #symb, BOOST_STRINGIZE(= symb) )
+#define BOOST_IS_DEFINED(symb) boost::test_tools::tt_detail::is_defined_impl( #symb, BOOST_STRINGIZE(= symb) )
 
 // ***************************** //
 // helper macros
@@ -154,15 +158,11 @@
 #define BOOST_CRITICAL_TEST(predicate)   BOOST_REQUIRE(predicate)
 #define BOOST_CRITICAL_ERROR(message_)   BOOST_FAIL(message_)
 
-#ifdef BOOST_MSVC
-# pragma warning(push)
-# pragma warning(disable: 4511) // copy constructor could not be generated
-# pragma warning(disable: 4512) // assignment operator could not be generated
-#endif
-
 namespace boost {
 
-namespace test_toolbox {
+namespace test_tools {
+
+typedef boost::unit_test::const_string      const_string;
 
 // ************************************************************************** //
 // **************            extended_predicate_value          ************** //
@@ -175,21 +175,17 @@ public:
     : p_predicate_value( predicate_value_ ), p_message( new wrap_stringstream ) {}
 
     extended_predicate_value( extended_predicate_value const& rhs )
-    : p_predicate_value( rhs.p_predicate_value.get() ), 
+    : p_predicate_value( rhs.p_predicate_value ), 
       p_message( rhs.p_message )                    {}
 
-    bool        operator!() const                   { return !p_predicate_value.get(); }
+    bool        operator!() const                   { return !p_predicate_value; }
     void        operator=( bool predicate_value_ )  { p_predicate_value.value = predicate_value_; }
 
-    BOOST_READONLY_PROPERTY( bool, 1, (extended_predicate_value) )
-                p_predicate_value;
-    boost::shared_ptr<wrap_stringstream>
-                p_message;
+    BOOST_READONLY_PROPERTY( bool, (extended_predicate_value) ) p_predicate_value;
+    boost::shared_ptr<wrap_stringstream>                        p_message;
 };
 
-namespace detail {
-
-using unit_test_framework::c_string_literal;
+namespace tt_detail {
 
 // ************************************************************************** //
 // **************                test_tool_failed              ************** //
@@ -229,7 +225,7 @@ struct print_log_value<unsigned char> {
 //____________________________________________________________________________//
 
 #define BOOST_TEST_DONT_PRINT_LOG_VALUE( the_type )                 \
-namespace boost { namespace test_toolbox { namespace detail {       \
+namespace boost { namespace test_tools { namespace tt_detail {      \
 template<>                                                          \
 struct print_log_value<the_type > {                                 \
     void operator()( std::ostream& ostr, the_type const& t ) {}     \
@@ -264,12 +260,12 @@ operator<<( std::ostream& ostr, print_helper<T> const& ph )
 // ************************************************************************** //
 
 void
-checkpoint_impl( wrap_stringstream& message_, c_string_literal file_name_, std::size_t line_num_ );
+checkpoint_impl( wrap_stringstream& message_, const_string file_name_, std::size_t line_num_ );
 
 //____________________________________________________________________________//
 
 void
-message_impl( wrap_stringstream& message_, c_string_literal file_name_, std::size_t line_num_ );
+message_impl( wrap_stringstream& message_, const_string file_name_, std::size_t line_num_ );
 
 //____________________________________________________________________________//
 
@@ -277,14 +273,14 @@ message_impl( wrap_stringstream& message_, c_string_literal file_name_, std::siz
 
 void
 warn_and_continue_impl( bool predicate_, wrap_stringstream& message_,
-                        c_string_literal file_name_, std::size_t line_num_,
+                        const_string file_name_, std::size_t line_num_,
                         bool add_fail_pass_ = true );
 
 //____________________________________________________________________________//
 
 void
 warn_and_continue_impl( extended_predicate_value const& v_, wrap_stringstream& message_,
-                        c_string_literal file_name_, std::size_t line_num_,
+                        const_string file_name_, std::size_t line_num_,
                         bool add_fail_pass_ = true );
 
 //____________________________________________________________________________//
@@ -293,22 +289,22 @@ warn_and_continue_impl( extended_predicate_value const& v_, wrap_stringstream& m
 
 bool  // return true if error detected
 test_and_continue_impl( bool predicate_, wrap_stringstream& message_,
-                        c_string_literal file_name_, std::size_t line_num_,
+                        const_string file_name_, std::size_t line_num_,
                         bool add_fail_pass_ = true,
-                        unit_test_framework::log_level log_level_ = unit_test_framework::log_all_errors );
+                        unit_test::log_level log_level_ = unit_test::log_all_errors );
 void
 test_and_throw_impl   ( bool predicate_, wrap_stringstream& message_,
-                        c_string_literal file_name_, std::size_t line_num_,
+                        const_string file_name_, std::size_t line_num_,
                         bool add_fail_pass_ = true,
-                        unit_test_framework::log_level log_level_ = unit_test_framework::log_fatal_errors );
+                        unit_test::log_level log_level_ = unit_test::log_fatal_errors );
 
 //____________________________________________________________________________//
 
 bool
 test_and_continue_impl( extended_predicate_value const& v_, wrap_stringstream& message_,
-                        c_string_literal file_name_, std::size_t line_num_,
+                        const_string file_name_, std::size_t line_num_,
                         bool add_fail_pass_ = true,
-                        unit_test_framework::log_level log_level_ = unit_test_framework::log_all_errors );
+                        unit_test::log_level log_level_ = unit_test::log_all_errors );
 
 //____________________________________________________________________________//
 
@@ -316,9 +312,9 @@ test_and_continue_impl( extended_predicate_value const& v_, wrap_stringstream& m
 #if BOOST_WORKAROUND(__BORLANDC__, <= 0x570)
 inline bool
 test_and_continue_impl( void* ptr, wrap_stringstream& message_,
-                        c_string_literal file_name_, std::size_t line_num_,
-                        bool add_fail_pass_ = true,
-                        unit_test_framework::log_level log_level_ = unit_test_framework::log_all_errors )
+                        const_string file_name_, std::size_t line_num_,
+                        bool add_fail_pass_             = true,
+                        unit_test::log_level log_level_ = unit_test::log_all_errors )
 {
     return test_and_continue_impl( !!ptr, message_, file_name_, line_num_, add_fail_pass_, log_level_ );
 }
@@ -328,9 +324,9 @@ test_and_continue_impl( void* ptr, wrap_stringstream& message_,
 
 void
 test_and_throw_impl   ( extended_predicate_value const& v_, wrap_stringstream& message_,
-                        c_string_literal file_name_, std::size_t line_num_,
+                        const_string file_name_, std::size_t line_num_,
                         bool add_fail_pass_ = true,
-                        unit_test_framework::log_level log_level_ = unit_test_framework::log_fatal_errors );
+                        unit_test::log_level log_level_ = unit_test::log_fatal_errors );
 
 //____________________________________________________________________________//
 
@@ -338,8 +334,8 @@ template<typename ArgType, typename Predicate>
 inline bool
 test_and_continue_impl( Predicate const& pred_, ArgType const& arg_,
                         wrap_stringstream& message_,
-                        c_string_literal file_name_, std::size_t line_num_,
-                        unit_test_framework::log_level log_level_ = unit_test_framework::log_all_errors )
+                        const_string file_name_, std::size_t line_num_,
+                        unit_test::log_level log_level_ = unit_test::log_all_errors )
 {
     extended_predicate_value predicate( pred_( arg_ ) );
 
@@ -359,8 +355,8 @@ template<typename ArgType, typename Predicate>
 inline void
 test_and_throw_impl   ( Predicate const& pred_, ArgType const& arg_,
                         wrap_stringstream& message_,
-                        c_string_literal file_name_, std::size_t line_num_,
-                        unit_test_framework::log_level log_level_ = unit_test_framework::log_fatal_errors )
+                        const_string file_name_, std::size_t line_num_,
+                        unit_test::log_level log_level_ = unit_test::log_fatal_errors )
 {
     if( test_and_continue_impl( arg_, pred_, message_, file_name_, line_num_, log_level_ ) ) {
         throw test_tool_failed(); // error already reported by test_and_continue_impl
@@ -373,8 +369,8 @@ template<typename First, typename Second, typename Predicate>
 inline bool
 test_and_continue_impl( Predicate const& pred_, First const& first_, Second const& second_,
                         wrap_stringstream& message_,
-                        c_string_literal file_name_, std::size_t line_num_,
-                        unit_test_framework::log_level log_level_ = unit_test_framework::log_all_errors )
+                        const_string file_name_, std::size_t line_num_,
+                        unit_test::log_level log_level_ = unit_test::log_all_errors )
 {
     extended_predicate_value predicate( pred_( first_, second_ ) );
 
@@ -394,8 +390,8 @@ test_and_continue_impl( Predicate const& pred_, First const& first_, Second cons
 template<typename First, typename Second, typename Predicate>
 inline void
 test_and_throw_impl( First const& first_, Second const& second_, Predicate const& pred_,
-                     wrap_stringstream& message_, c_string_literal file_name_, std::size_t line_num_,
-                     unit_test_framework::log_level log_level_ = unit_test_framework::log_fatal_errors )
+                     wrap_stringstream& message_, const_string file_name_, std::size_t line_num_,
+                     unit_test::log_level log_level_ = unit_test::log_fatal_errors )
 {
     if( test_and_continue_impl( first_, second_, pred_, message_, file_name_, line_num_, log_level_ ) ) {
         throw test_tool_failed(); // error already reported by test_and_continue_impl
@@ -407,18 +403,27 @@ test_and_throw_impl( First const& first_, Second const& second_, Predicate const
 // ************************************* //
 
 bool
-equal_and_continue_impl( c_string_literal left_, c_string_literal right_, wrap_stringstream& message_,
-                         c_string_literal file_name_, std::size_t line_num_,
-                         unit_test_framework::log_level log_level_ = unit_test_framework::log_all_errors );
+equal_and_continue_impl( char const* left_, char const* right_, wrap_stringstream& message_,
+                         const_string file_name_, std::size_t line_num_,
+                         unit_test::log_level log_level_ = unit_test::log_all_errors );
+
+//____________________________________________________________________________//
+
+#if !defined( BOOST_NO_CWCHAR )
+bool
+equal_and_continue_impl( wchar_t const* left_, wchar_t const* right_, wrap_stringstream& message_,
+                         const_string file_name_, std::size_t line_num_,
+                         unit_test::log_level log_level_ = unit_test::log_all_errors );
+#endif // !defined( BOOST_NO_CWCHAR )
 
 //____________________________________________________________________________//
 
 template <class Left, class Right>
 inline bool
 equal_and_continue_impl( Left const& left_, Right const& right_,
-                         wrap_stringstream& message_, c_string_literal file_name_, std::size_t line_num_,
-                         unit_test_framework::log_level log_level_ = unit_test_framework::log_all_errors,
-                         std::size_t pos = (std::size_t)-1 )
+                         wrap_stringstream& message_, const_string file_name_, std::size_t line_num_,
+                         unit_test::log_level log_level_ = unit_test::log_all_errors,
+                         std::size_t pos                 = (std::size_t)-1 )
 {
     extended_predicate_value predicate( left_ == right_ );
 
@@ -446,8 +451,8 @@ template <class Left, class Right>
 inline void
 equal_and_continue_impl( Left left_begin_, Left left_end_, Right right_begin_,
                          wrap_stringstream& message_,
-                         c_string_literal file_name_, std::size_t line_num_,
-                         unit_test_framework::log_level log_level_ = unit_test_framework::log_all_errors )
+                         const_string file_name_, std::size_t line_num_,
+                         unit_test::log_level log_level_ = unit_test::log_all_errors )
 {
     std::size_t pos = 0;
     for( ; left_begin_ != left_end_; ++left_begin_, ++right_begin_, ++pos )
@@ -461,11 +466,11 @@ equal_and_continue_impl( Left left_begin_, Left left_end_, Right right_begin_,
 template<typename FPT, typename PersentType>
 inline bool
 compare_and_continue_impl( FPT left_, FPT right_, PersentType tolerance_,
-                           c_string_literal left_text_, c_string_literal right_text_,
-                           c_string_literal file_name_, std::size_t line_num_,
-                           unit_test_framework::log_level log_level_ = unit_test_framework::log_all_errors )
+                           const_string left_text_, const_string right_text_,
+                           const_string file_name_, std::size_t line_num_,
+                           unit_test::log_level log_level_ = unit_test::log_all_errors )
 {
-    extended_predicate_value predicate( check_is_closed( left_, right_, tolerance_ ) );
+    extended_predicate_value predicate( check_is_close( left_, right_, tolerance_ ) );
 
     if( !predicate ) {
         return test_and_continue_impl( predicate,
@@ -487,8 +492,8 @@ compare_and_continue_impl( FPT left_, FPT right_, PersentType tolerance_,
 template <class Left, class Right>
 inline void
 bitwise_equal_and_continue_impl( Left const& left_, Right const& right_,
-                                 wrap_stringstream& message_, char const* file_name_, std::size_t line_num_,
-                                 unit_test_framework::log_level log_level_ = unit_test_framework::log_all_errors )
+                                 wrap_stringstream& message_, const_string file_name_, std::size_t line_num_,
+                                 unit_test::log_level log_level_ = unit_test::log_all_errors )
 {
     std::size_t left_bit_size  = sizeof(Left)*CHAR_BIT;
     std::size_t right_bit_size = sizeof(Right)*CHAR_BIT;
@@ -515,11 +520,11 @@ bitwise_equal_and_continue_impl( Left const& left_, Right const& right_,
 // ************************************* //
 
 bool
-is_defined_impl( c_string_literal symbol_name_, c_string_literal symbol_value_ );
+is_defined_impl( const_string symbol_name_, const_string symbol_value_ );
 
 //____________________________________________________________________________//
 
-} // namespace detail
+} // namespace tt_detail
 
 // ************************************************************************** //
 // **************               output_test_stream             ************** //
@@ -534,14 +539,11 @@ class output_test_stream : public
     std::ostringstream
 #endif // BOOST_NO_STRINGSTREAM
 {
-    typedef extended_predicate_value                result_type;
-    typedef unit_test_framework::c_string_literal   c_string_literal;
+    typedef extended_predicate_value    result_type;
 public:
     // Constructor
-    explicit        output_test_stream( std::string const&  pattern_file_name = std::string(),
-                                        bool                match_or_save     = true );
-    explicit        output_test_stream( c_string_literal    pattern_file_name,
-                                        bool                match_or_save     = true );
+    explicit        output_test_stream( const_string    pattern_file_name = const_string(),
+                                        bool            match_or_save     = true );
 
     // Destructor
     ~output_test_stream();
@@ -549,9 +551,7 @@ public:
     // checking function
     result_type     is_empty( bool flush_stream_ = true );
     result_type     check_length( std::size_t length_, bool flush_stream_ = true );
-    result_type     is_equal( c_string_literal arg_, bool flush_stream_ = true );
-    result_type     is_equal( std::string const& arg_, bool flush_stream_ = true );
-    result_type     is_equal( c_string_literal arg_, std::size_t n_, bool flush_stream_ = true );
+    result_type     is_equal( const_string arg_, bool flush_stream_ = true );
     result_type     match_pattern( bool flush_stream_ = true );
 
     // helper function
@@ -565,22 +565,46 @@ private:
     boost::shared_ptr<Impl> m_pimpl;
 };
 
-} // namespace test_toolbox
+} // namespace test_tools
+
+namespace test_toolbox = test_tools;
 
 } // namespace boost
 
-#ifdef BOOST_MSVC
-# pragma warning(default: 4511) // copy constructor could not be generated
-# pragma warning(default: 4512) // assignment operator could not be generated
-# pragma warning(pop)
-#endif
+#include <boost/test/detail/enable_warnings.hpp>
 
 // ***************************************************************************
 //  Revision History :
 //
 //  $Log: test_tools.hpp,v $
-//  Revision 1.35.2.1  2004/01/06 13:33:28  johnmaddock
-//  merged changes from main branch
+//  Revision 1.45  2004/07/25 08:31:10  rogeeff
+//  don't use wchar if BOOST_NO_CWCHAR is defined
+//
+//  Revision 1.44  2004/07/19 12:15:45  rogeeff
+//  guard rename
+//  warning suppress reworked
+//
+//  Revision 1.43  2004/06/07 07:33:49  rogeeff
+//  detail namespace renamed
+//
+//  Revision 1.42  2004/06/05 10:59:58  rogeeff
+//  proper IBM VA port
+//
+//  Revision 1.41  2004/06/03 10:38:31  tknapen
+//  port to vacpp version 6
+//
+//  Revision 1.40  2004/05/27 06:36:26  rogeeff
+//  eliminate c_string_literal typedef
+//
+//  Revision 1.39  2004/05/27 06:20:53  rogeeff
+//  wide C string comparison support added
+//
+//  Revision 1.38  2004/05/21 06:19:35  rogeeff
+//  licence update
+//
+//  Revision 1.37  2004/05/11 11:00:35  rogeeff
+//  basic_cstring introduced and used everywhere
+//  class properties reworked
 //
 //  Revision 1.36  2004/01/05 11:56:25  johnmaddock
 //  Borland specific workaround needs to be inline to prevent linker errors, and is unneeded for version 6 of the compiler.
@@ -588,7 +612,6 @@ private:
 //  Revision 1.35  2003/12/01 00:41:56  rogeeff
 //  prerelease cleaning
 //
-
 // ***************************************************************************
 
-#endif // BOOST_TEST_TOOLS_HPP
+#endif // BOOST_TEST_TOOLS_HPP_071894GER
