@@ -1,8 +1,7 @@
-// (C) Copyright Jeremy Siek 2000. Permission to copy, use, modify,
-// sell and distribute this software is granted provided this
-// copyright notice appears in all copies. This software is provided
-// "as is" without express or implied warranty, and with no claim as
-// to its suitability for any purpose.
+// (C) Copyright Jeremy Siek 2000.
+// Distributed under the Boost Software License, Version 1.0. (See
+// accompanying file LICENSE_1_0.txt or copy at
+// http://www.boost.org/LICENSE_1_0.txt)
 //
 // Change Log:
 // 20 Jan 2001 - Added warning suppression (David Abrahams)
@@ -18,11 +17,9 @@
 
 struct foo { };
 
-using namespace boost;
-
 class class_requires_test
 {
-  BOOST_CLASS_REQUIRES(foo, EqualityComparableConcept);
+  BOOST_CLASS_REQUIRE(foo, boost, EqualityComparableConcept);
 };
 
 int
