@@ -1,8 +1,7 @@
-// Copyright David Abrahams 2001. Permission to copy, use,
-// modify, sell and distribute this software is granted provided this
-// copyright notice appears in all copies. This software is provided
-// "as is" without express or implied warranty, and with no claim as
-// to its suitability for any purpose.
+// Copyright David Abrahams 2001.
+// Distributed under the Boost Software License, Version 1.0. (See
+// accompanying file LICENSE_1_0.txt or copy at
+// http://www.boost.org/LICENSE_1_0.txt)
 
 #include <boost/python/object/function.hpp>
 #include <boost/python/object/function_object.hpp>
@@ -99,7 +98,10 @@ function::function(
         function_type.ob_type = &PyType_Type;
         ::PyType_Ready(&function_type);
     }
-    PyObject_INIT(p, &function_type);
+    
+    (void)(     // warning suppression for GCC
+        PyObject_INIT(p, &function_type)
+    );
 }
 
 function::~function()
