@@ -1,16 +1,11 @@
 /* statistic_tests.hpp header file
  *
  * Copyright Jens Maurer 2000
- * Permission to use, copy, modify, sell, and distribute this software
- * is hereby granted without fee provided that the above copyright notice
- * appears in all copies and that both that copyright notice and this
- * permission notice appear in supporting documentation,
+ * Distributed under the Boost Software License, Version 1.0. (See
+ * accompanying file LICENSE_1_0.txt or copy at
+ * http://www.boost.org/LICENSE_1_0.txt)
  *
- * Jens Maurer makes no representations about the suitability of this
- * software for any purpose. It is provided "as is" without express or
- * implied warranty.
- *
- * $Id: statistic_tests.hpp,v 1.10 2002/11/01 20:02:24 jmaurer Exp $
+ * $Id: statistic_tests.hpp,v 1.13 2004/07/27 03:43:34 dgregor Exp $
  *
  */
 
@@ -91,8 +86,8 @@ public:
   template<class NumberGenerator, class Counter>
   void run(NumberGenerator f, Counter & count, int n) const
   {
-    assert(f.min() == 0 &&
-           static_cast<unsigned int>(f.max()) == classes()-1);
+    assert((f.min)() == 0 &&
+           static_cast<unsigned int>((f.max)()) == classes()-1);
     for(int i = 0; i < n; ++i)
       count(f());
   }
@@ -109,8 +104,8 @@ public:
   template<class NumberGenerator, class Counter>
   void run(NumberGenerator f, Counter & count, int n) const
   {
-    unsigned int range = f.max()+1;
-    assert(f.min() == 0 && range*range == classes());
+    unsigned int range = (f.max)()+1;
+    assert((f.min)() == 0 && range*range == classes());
     for(int i = 0; i < n; ++i) {
       int y1 = f();
       int y2 = f();
@@ -131,8 +126,8 @@ public:
     for(unsigned int i = 0; i < classes-1; ++i)
       limit[i] = invert_monotone_inc(probability, (i+1)*0.05, 0, 1000);
     limit[classes-1] = std::numeric_limits<double>::infinity();
-    if(limit[classes-1] < std::numeric_limits<double>::max())
-      limit[classes-1] = std::numeric_limits<double>::max();
+    if(limit[classes-1] < (std::numeric_limits<double>::max)())
+      limit[classes-1] = (std::numeric_limits<double>::max)();
 #if 0
     std::cout << __PRETTY_FUNCTION__ << ": ";
     for(unsigned int i = 0; i < classes; ++i)
@@ -166,7 +161,7 @@ public:
   void run(UniformRandomNumberGenerator f, Counter & count, int n) const
   {
     typedef typename UniformRandomNumberGenerator::result_type result_type;
-    result_type init = (up ? f.min() : f.max());
+    result_type init = (up ? (f.min)() : (f.max)());
     result_type previous = init;
     unsigned int length = 0;
     for(int i = 0; i < n; ++i) {
@@ -175,7 +170,7 @@ public:
         previous = val;
         ++length;
       } else {
-        count(std::min(length, classes())-1);
+        count((std::min)(length, classes())-1);
         length = 0;
         previous = init;
         // don't use this value, so that runs are independent
@@ -202,16 +197,16 @@ public:
   void run(UniformRandomNumberGenerator f, Counter & count, int n) const
   {
     typedef typename UniformRandomNumberGenerator::result_type result_type;
-    double range = f.max() - f.min() + 1.0;
+    double range = (f.max)() - (f.min)() + 1.0;
     result_type low = static_cast<result_type>(alpha * range);
     result_type high = static_cast<result_type>(beta * range);
     unsigned int length = 0;
     for(int i = 0; i < n; ) {
-      result_type value = f() - f.min();
+      result_type value = f() - (f.min)();
       if(value < low || value > high)
         ++length;
       else {
-        count(std::min(length, classes()-1));
+        count((std::min)(length, classes()-1));
         length = 0;
         ++i;
       }
@@ -244,8 +239,8 @@ public:
   {
     typedef typename UniformRandomNumberGenerator::result_type result_type;
     assert(std::numeric_limits<result_type>::is_integer);
-    assert(f.min() == 0);
-    assert(f.max() == static_cast<result_type>(range-1));
+    assert((f.min)() == 0);
+    assert((f.max)() == static_cast<result_type>(range-1));
     std::vector<result_type> v(classes());
     for(int i = 0; i < n; ++i) {
       for(unsigned int j = 0; j < classes(); ++j)
@@ -291,8 +286,8 @@ public:
   {
     typedef typename UniformRandomNumberGenerator::result_type result_type;
     assert(std::numeric_limits<result_type>::is_integer);
-    assert(f.min() == 0);
-    assert(f.max() == static_cast<result_type>(d-1));
+    assert((f.min)() == 0);
+    assert((f.max)() == static_cast<result_type>(d-1));
     std::vector<bool> occurs(d);
     for(int i = 0; i < n; ++i) {
       occurs.assign(d, false);
@@ -308,7 +303,7 @@ public:
             break;     // one complete set
         }
       }
-      count(std::min(r-d, classes()-1));
+      count((std::min)(r-d, classes()-1));
     }
   }
   double probability(unsigned int r) const
@@ -369,8 +364,8 @@ public:
   {
     typedef typename UniformRandomNumberGenerator::result_type result_type;
     assert(std::numeric_limits<result_type>::is_integer);
-    assert(f.min() == 0);
-    assert(f.max() == static_cast<result_type>(m-1));
+    assert((f.min)() == 0);
+    assert((f.max)() == static_cast<result_type>(m-1));
    
     for(int j = 0; j < n_total; j++) {
       std::vector<result_type> v(n);
@@ -386,7 +381,7 @@ public:
         if(spacing[i] == spacing[i+1])
           ++k;
       }
-      count(std::min(k, classes()-1));
+      count((std::min)(k, classes()-1));
     }
   }
 
@@ -469,17 +464,17 @@ public:
       int k = static_cast<int>(std::floor(m*y));
       if(k >= m)
         --k;    // should not happen
-      a[k] = std::min(a[k], y);
-      b[k] = std::max(b[k], y);
+      a[k] = (std::min)(a[k], y);
+      b[k] = (std::max)(b[k], y);
       ++c[k];
     }
     double kplus = 0, kminus = 0;
     int j = 0;
     for(int k = 0; k < m; ++k) {
       if(c[k] > 0) {
-        kminus = std::max(kminus, a[k]-j/static_cast<double>(n));
+        kminus = (std::max)(kminus, a[k]-j/static_cast<double>(n));
         j += c[k];
-        kplus = std::max(kplus, j/static_cast<double>(n) - b[k]);
+        kplus = (std::max)(kplus, j/static_cast<double>(n) - b[k]);
       }
     }
     kplus *= std::sqrt(double(n));
@@ -519,7 +514,7 @@ private:
     {
       double mx = f();
       for(int i = 1; i < t; ++i)
-        mx = std::max(mx, f());
+        mx = (std::max)(mx, f());
       return mx;
     }
   private:
